Class: Test::Unit::TestCase
- Inherits:
-
Object
- Object
- Test::Unit::TestCase
- Extended by:
- SharedShould::SharedContext
- Defined in:
- lib/shared_should/test_unit_hooks.rb,
lib/shared_should/test_unit_hooks.rb
Class Method Summary collapse
- .suite ⇒ Object
-
.suite_without_shared_should_execute ⇒ Object
these methods need to be aliased for both the test class and the should context.
Methods included from SharedShould::SharedContext
Class Method Details
.suite ⇒ Object
34 35 36 37 38 39 |
# File 'lib/shared_should/test_unit_hooks.rb', line 34 def self.suite # assuming 'suite' is called before executing any tests - may be a poor assumption. Find something better? execute_class_shared_proxies suite_without_shared_should_execute end |
.suite_without_shared_should_execute ⇒ Object
these methods need to be aliased for both the test class and the should context
27 |
# File 'lib/shared_should/test_unit_hooks.rb', line 27 alias_method :suite_without_shared_should_execute, :suite |